Introduction
============

Simple package which makes jQuery UI Chatbox available in portal_javascript and
portal_css. This package does not change nor define any view or templates. It 
basically does nothing from the user point of view. It is usable for template 
developers to avoid several chatbox libraries registered from different 
products

More Information
=================

For more information about this plugin, and how to use it, check out 
http://magma.cs.uiuc.edu/wenpu1/chatbox.html and
https://github.com/dexterpu/jquery.ui.chatbox
